-- Josephine Suen, jsuen

CREATE TABLE Campuses(
   id             INT         PRIMARY KEY,
   campus         VARCHAR(64) UNIQUE NOT NULL,
   location       VARCHAR(16) UNIQUE NOT NULL,
   county         VARCHAR(16) NOT NULL,
   year           INT         NOT NULL
);

CREATE TABLE CSUFees(
   campus         INT         NOT NULL,
   year           INT         NOT NULL,
   campusFee      INT         NOT NULL,
   CONSTRAINT pk_CampusYear PRIMARY KEY(campus, year),
   CONSTRAINT fk_Campus FOREIGN KEY(campus) REFERENCES Campuses(id)
);

CREATE TABLE Degrees(
   year           INT         NOT NULL,
   campus         INT         NOT NULL,
   degrees        INT         NOT NULL,
   CONSTRAINT pk_CampusYear PRIMARY KEY(campus, year),
   CONSTRAINT fk_DegCampus FOREIGN KEY(campus) REFERENCES Campuses(id)
);

CREATE TABLE Disciplines(
   id             INT         PRIMARY KEY,
   name           VARCHAR(32) UNIQUE NOT NULL
);

CREATE TABLE DisciplineEnrollments(
   campus         INT         NOT NULL,
   discipline     INT         NOT NULL,
   year           INT         NOT NULL,
   undergraduate  INT         NOT NULL,
   graduate       INT         NOT NULL,
   CONSTRAINT pk_DECampusYear PRIMARY KEY(campus, year, discipline),
   CONSTRAINT fk_DECampus FOREIGN KEY(campus) REFERENCES Campuses(id),
   CONSTRAINT fk_Discipline FOREIGN KEY(discipline) REFERENCES Disciplines(id)
);

CREATE TABLE Enrollments(
   campus            INT      NOT NULL,
   year              INT      NOT NULL,
   totalEnrollment   INT      NOT NULL,
   fullTimeEnroll    INT      NOT NULL,
   CONSTRAINT pk_EnrCampusYear PRIMARY KEY(campus, year),
   CONSTRAINT fk_EnrCampus FOREIGN KEY(campus) REFERENCES Campuses(id)
);

CREATE TABLE Faculty(
   campus         INT         NOT NULL,
   year           INT         NOT NULL,
   faculty        FLOAT       NOT NULL,
   CONSTRAINT pk_FacCampusYear PRIMARY KEY(campus, year),
   CONSTRAINT fk_FacCampus FOREIGN KEY(campus) REFERENCES Campuses(id)
);